pub enum AuthorizeError {
Show 13 variants
ProcessTokens(JwtProcessingError),
Action(Box<ParseErrors>),
IdentifierParsing(Box<ParseErrors>),
CreateContext(Box<ContextJsonError>),
InvalidPrincipal(Box<InvalidPrincipalError>),
RequestValidation(Box<RequestValidationError>),
ValidateEntities(Box<EntitiesError>),
EntitiesToJson(Error),
BuildContext(BuildContextError),
BuildEntity(BuildEntityError),
BuildUnsignedRoleEntity(BuildUnsignedEntityError),
MultiIssuerValidation(MultiIssuerValidationError),
MultiIssuerEntity(MultiIssuerEntityError),
}Expand description
Error type for Authorization Service
Variants
ProcessTokens(JwtProcessingError)
Error encountered while processing JWT token data
Action(Box<ParseErrors>)
Error encountered while parsing Action to EntityUid
IdentifierParsing(Box<ParseErrors>)
Error encountered while parsing an entity type name or action identifier
CreateContext(Box<ContextJsonError>)
Error encountered while validating context according to the schema
InvalidPrincipal(Box<InvalidPrincipalError>)
Error encountered while creating cedar_policy::Request for entity principal
RequestValidation(Box<RequestValidationError>)
Error encountered while validating the Cedar request
ValidateEntities(Box<EntitiesError>)
Error encountered while checking if the Entities adhere to the schema
EntitiesToJson(Error)
Error encountered while parsing all entities to json for logging
BuildContext(BuildContextError)
Error encountered while building the context for the request
BuildEntity(BuildEntityError)
Error encountered while building Cedar Entities
BuildUnsignedRoleEntity(BuildUnsignedEntityError)
Error encountered while building Role entity in an unsigned request
MultiIssuerValidation(MultiIssuerValidationError)
Error encountered while validating multi-issuer request
MultiIssuerEntity(MultiIssuerEntityError)
Error encountered while building multi-issuer entities