pub enum BootstrapConfigLoadingError {
Show 14 variants
InvalidFileFormat(String),
ReadFile(String, Error),
DecodingJSON(String),
DecodingYAML(String),
DecodingTOML(String),
MissingLogTTL,
ConflictingPolicyStores,
MissingPolicyStore,
UnsupportedPolicyStoreFileFormat(String),
LoadLocalJwks(String, String),
MissingLockServerConfigUri,
InvalidLockServerConfigUri(ParseError),
MissingCjarUrl,
MissingGrpcEndpoint,
}Expand description
Represents errors that may occur while loading a BootstrapConfig from a file.
Variants
InvalidFileFormat(String)
Error returned when the file format is unsupported.
Supported formats include:
.json.yamlor.yml.toml
ReadFile(String, Error)
Error returned when the file cannot be read.
DecodingJSON(String)
Error returned when parsing the file as JSON fails.
DecodingYAML(String)
Error returned when parsing the file as YAML fails.
DecodingTOML(String)
Error returned when parsing the file as TOML fails.
MissingLogTTL
Error returned when the boostrap property CEDARLING_LOG_TTL is missing.
ConflictingPolicyStores
Error returned when multiple policy store sources were provided.
MissingPolicyStore
Error returned when no policy store source was provided.
UnsupportedPolicyStoreFileFormat(String)
Error returned when the policy store file is in an unsupported format.
LoadLocalJwks(String, String)
Error returned when failing to load a local JWKS
MissingLockServerConfigUri
Error returned when CEDARLING_LOCK is set to enabled but CEDARLING_LOCK_SERVER_CONFIGURATION_URI is not set.
InvalidLockServerConfigUri(ParseError)
Error returned when the lock server configuration URI is invalid.
MissingCjarUrl
Error returned when cjar_url is missing or empty.
MissingGrpcEndpoint
Error returned when transport is set to gRPC but no gRPC endpoint is configured.