Module jwt_config

Module jwt_config 

JWT config module

Structs

JwtConfig
The set of Bootstrap properties related to JWT validation.
WorkersCount
A wrapper around NonZeroUsize that enforces a maximum value. This is used to ensure that the number of workers for loading trusted issuers does not exceed a reasonable limit. The maximum value is defined based on the target architecture to prevent excessive resource usage.

Enums

TrustedIssuerLoaderConfig
Config structure that define how trusted issuers will be loaded.
TrustedIssuerLoaderTypeRaw
Raw representation of trusted issuer loader type from environment variable. Is used in [BootstrapConfigRaw].