pub struct WorkersCount(/* private fields */);Expand description
A wrapper around NonZeroUsize that enforces a maximum value.
This is used to ensure that the number of workers for loading trusted issuers does not exceed a reasonable limit.
The maximum value is defined based on the target architecture to prevent excessive resource usage.
On non-WebAssembly targets, the maximum is set to 1000, while on WebAssembly targets, it is set to 4 to align with typical browser limits on concurrent HTTP connections.
Implementations
Sourceimpl WorkersCount
impl WorkersCount
Sourcepub const MAX: WorkersCount
pub const MAX: WorkersCount
Maximum number of workers is 1000 to prevent excessive resource usage.
Sourcepub const DEFAULT: WorkersCount
pub const DEFAULT: WorkersCount
For native architecture default value is 10. Should cover most of cases.
Sourceimpl WorkersCount
impl WorkersCount
Sourcepub const MIN: WorkersCount
pub const MIN: WorkersCount
Minimum number of workers is 1.