pub struct LockServiceConfig {
pub log_level: LogLevel,
pub config_uri: Url,
pub dynamic_config: bool,
pub ssa_jwt: Option<String>,
pub log_interval: Option<Duration>,
pub health_interval: Option<Duration>,
pub telemetry_interval: Option<Duration>,
pub listen_sse: bool,
pub accept_invalid_certs: bool,
}Expand description
Config for the lock logger that are set using the bootstrap configs.
Fields
log_level: LogLevelThe logging level
config_uri: UrlURI where Cedarling can get metadata about the lock server.
i.e. .well-known/lock-server-configuration
This is set using the CEDARLING_LOCK_SERVER_CONFIGURATION_URI bootstrap property.
dynamic_config: boolToggles whether Cedarling should listen for SSE config updates.
This is set using the CEDARLING_LOCK_DYNAMIC_CONFIGURATION bootstrap property.
ssa_jwt: Option<String>Software Statement Assertion Json Web Token that Cedarling will use for Dynamic Client Registration.
This is set using the CEDARLING_LOCK_SSA_JWT bootstrap property.
log_interval: Option<Duration>Intervals to send log messges to the lock server.
Set this to None to disable transmission.
This is set using the CEDARLING_LOCK_LOG_INTERVAL bootstrap property.
health_interval: Option<Duration>Intervals to send health messges to the lock server.
Set this to None to disable transmission.
This is set using the CEDARLING_LOCK_HEALTH_INTERVAL bootstrap property.
telemetry_interval: Option<Duration>Intervals to send telemetry messges to the lock server.
Set this to None to disable transmission.
This is set using the CEDARLING_LOCK_TELEMETRY_INTERVAL bootstrap property.
listen_sse: boolControls whether Cedarling should listen for updates from the Lock Server.
This is set using the CEDARLING_LOCK_LISTEN_SSE bootstrap property.
accept_invalid_certs: boolAllow interaction with a Lock server with invalid certificates. Used for testing.