pub struct MemoryLogConfig {
pub log_ttl: u64,
pub max_items: Option<usize>,
pub max_item_size: Option<usize>,
}Expand description
Configuration for memory log.
Fields
log_ttl: u64CEDARLING_LOG_TTL in bootstrap properties documentation.
The maximum time to live (in seconds) of the log entries.
max_items: Option<usize>CEDARLING_LOG_MAX_ITEMS in bootstrap properties documentation.
The maximum number of log entries to keep in memory.
max_item_size: Option<usize>CEDARLING_LOG_MAX_ITEM_SIZE in bootstrap properties documentation.
The maximum size of a log entry in bytes.