JWT config module
Structs
- JwtConfig
- The set of Bootstrap properties related to JWT validation.
- Workers
Count - A wrapper around
NonZeroUsizethat enforces a maximum value. This is used to ensure that the number of workers for loading trusted issuers does not exceed a reasonable limit. The maximum value is defined based on the target architecture to prevent excessive resource usage.
Enums
- Trusted
Issuer Loader Config - Config structure that define how trusted issuers will be loaded.
- Trusted
Issuer Loader Type Raw - Raw representation of trusted issuer loader type from environment variable.
Is used in [
BootstrapConfigRaw].