pub struct LockServiceConfig {Show 13 fields
pub log_level: LogLevel,
pub config_uri: Url,
pub dynamic_config: bool,
pub ssa_jwt: Option<String>,
pub access_token_jwt: Option<String>,
pub log_interval: Option<Duration>,
pub health_interval: Option<Duration>,
pub telemetry_interval: Option<Duration>,
pub listen_sse: bool,
pub accept_invalid_certs: bool,
pub transport: LockTransport,
pub log_channel_capacity: usize,
pub log_max_retries: u32,
}Expand description
Lock service config
Fields
log_level: LogLevelThe logging level
config_uri: UrlURI where Cedarling can get metadata about the lock server.
i.e. .well-known/lock-server-configuration
dynamic_config: boolToggles whether Cedarling should listen for SSE config updates.
ssa_jwt: Option<String>Software Statement Assertion Json Web Token that Cedarling will use for Dynamic Client Registration.
access_token_jwt: Option<String>Pre-issued access token for Lock Server authentication.
When set, Cedarling skips the SSA → DCR → access_token flow and uses this
token directly. If both ssa_jwt and access_token_jwt are present,
access_token_jwt takes precedence.
Not available on WASM targets.
log_interval: Option<Duration>Intervals to send log messages to the lock server.
Set this to None to disable transmission.
health_interval: Option<Duration>Intervals to send health messages to the lock server.
Set this to None to disable transmission.
telemetry_interval: Option<Duration>Intervals to send telemetry messages to the lock server.
Set this to None to disable transmission.
listen_sse: boolControls whether Cedarling should listen for updates from the Lock Server.
accept_invalid_certs: boolAllow interaction with a Lock server with invalid certificates. Used for testing.
transport: LockTransportTransport protocol to use for Lock Server communication
log_channel_capacity: usizeChannel capacity for buffering log entries before they are sent to the lock server.
log_max_retries: u32Maximum number of retry attempts for sending logs to the lock server.